@@ -17,9 +17,9 @@ logging.basicConfig(
 
 
 class DBConnect:
-    def __init__(self, db: str, collection: str, home_key='MONGODB_HOST', port_key='MONGODB_PORT'):
-        self.mongo_home = os.environ.get(home_key, '127.0.0.1')
-        self.mongo_port = os.environ.get(port_key, 27017)
+    def __init__(self, db: str, collection: str, home_key='MONGODB_HOST', port_key='MONGODB_PORT', home_key):
+        self.mongo_home = os.environ.get(home_key, None)
+        self.mongo_port = os.environ.get(port_key, None)
 
         if not self.mongo_home or not self.mongo_port:
             logging.error('MongoDB(组件)的组件连接信息是不完整的')
