@@ -43,6 +43,7 @@ class Parameter():
                 status=400,
                 other={'prompt': json_data}
             )
+        redundant_dict = {}  # 未预先定义的额外参数字典
         for _k, _v in checking.items():
             try:
                 str_data = None
@@ -77,11 +78,8 @@ class Parameter():
                         other={'prompt': str_data}
                     )
             except KeyError as err:
-                handle_abnormal(
-                    message='有多余的请求参数',
-                    status=400,
-                    other={'prompt': str(err)}
-                )
+                redundant_dict[_k] = _v  # 收集多余的参数
+        checking['redundant_dict'] = redundant_dict
         return checking
 
     def verification_file(self, verify_field: list, verify_suffix: list = []):
